@@ -264,7 +264,7 @@ def _weave_class(target, aspect, skip_magic_methods, skip_subclasses, on_init, s
             if not issubclass(sub_class, Fabric):
                 rollbacks.extend(_weave_class(
                     sub_class, aspect, skip_magic_methods, skip_subclasses, on_init, skip_methods, only_methods,
-                    force_module=force_module, force_name=force_name
+                    force_module=force_module
                 ))
     if on_init:
         logger.debug("Weaving %r as class (on demand at __init__ time).", target)
